@@ -6,7 +6,7 @@
 #ifndef _IP_VS_H
 #define _IP_VS_H
 
-#define IP_VS_VERSION_CODE            0x00020C
+#define IP_VS_VERSION_CODE            0x000800
 #define NVERSION(version)                       \
         (version >> 16) & 0xFF,                 \
         (version >> 8) & 0xFF,                  \
@@ -182,7 +182,6 @@ enum {
 	NET_IPV4_VS_TO_ICMP=18,
 	NET_IPV4_VS_LBLC_EXPIRE=19,
 	NET_IPV4_VS_LBLCR_EXPIRE=20,
-	NET_IPV4_VS_USE_DST=21,
 	NET_IPV4_VS_CACHE_BYPASS=22,
 };
 
@@ -428,8 +427,6 @@ extern unsigned int check_for_ip_vs_out(struct sk_buff **skb_p,
 extern struct ip_vs_timeout_table vs_timeout_table;
 extern struct ip_vs_timeout_table vs_timeout_table_dos;
 
-extern int ip_vs_conn_hash(struct ip_vs_conn *cp);
-extern int ip_vs_conn_unhash(struct ip_vs_conn *cp);
 extern struct ip_vs_conn *ip_vs_conn_in_get
 (int protocol, __u32 s_addr, __u16 s_port, __u32 d_addr, __u16 d_port);
 extern struct ip_vs_conn *ip_vs_conn_out_get
@@ -537,7 +534,6 @@ extern struct ip_vs_scheduler *ip_vs_lookup_scheduler(const char *sched_name);
  *      IPVS control data and functions
  *      (from ip_vs_ctl.c)
  */
-extern int sysctl_use_dst;
 extern int sysctl_ip_vs_cache_bypass;
 extern atomic_t ip_vs_dropentry;
 extern struct ip_vs_stats ip_vs_stats;
