@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.15.2.3 2001/05/05 14:13:57 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.15.2.4 2001/05/09 08:00:16 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -757,7 +757,7 @@ static int ip_vs_nat_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 	dest = cp->dest;
 	rtos = RT_TOS(tos);
 	spin_lock(&dest->dst_lock);
-	if (!sysctl_use_dst || !(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
+	if (!(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
 		if (ip_route_output(&rt, dest->addr, 0, rtos, 0)) {
 			spin_unlock(&dest->dst_lock);
 			IP_VS_DBG(0, "ip_vs_nat_xmit(): route error, "
@@ -904,7 +904,7 @@ static int ip_vs_tunnel_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 	dest = cp->dest;
 	rtos = RT_TOS(tos);
 	spin_lock(&dest->dst_lock);
-	if (!sysctl_use_dst || !(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
+	if (!(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
 		if (ip_route_output(&rt, dest->addr, 0, rtos, 0)) {
 			spin_unlock(&dest->dst_lock);
 			IP_VS_DBG(0, "ip_vs_tunnel_xmit(): route error, "
@@ -1019,7 +1019,7 @@ static int ip_vs_dr_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 	dest = cp->dest;
 	rtos = RT_TOS(tos);
 	spin_lock(&dest->dst_lock);
-	if (!sysctl_use_dst || !(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
+	if (!(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
 		if (ip_route_output(&rt, dest->addr, 0, rtos, 0)) {
 			spin_unlock(&dest->dst_lock);
 			IP_VS_DBG(0, "ip_vs_dr_xmit(): route error, "
