@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.17 2001/04/04 02:53:11 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.17.2.1 2001/05/09 08:00:16 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -1016,7 +1016,7 @@ static int ip_vs_in_icmp(struct sk_buff **skb_p)
 	dest = cp->dest;
 	rtos = RT_TOS(tos);
 	spin_lock(&dest->dst_lock);
-	if (!sysctl_use_dst || !(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
+	if (!(rt = (struct rtable *) __ip_vs_dst_check(dest, rtos, 0))) {
 		if (ip_route_output(&rt, dest->addr, 0, rtos, 0)) {
 			spin_unlock(&dest->dst_lock);
 			IP_VS_DBG(0, "ip_vs_in_imcp(): route error, "
